Package: accbaseballr
Title: ACC Baseball Datasets with Advanced Sabermetric Metrics
Version: 0.1.4
Authors@R: 
    person("Hana", "Baskin", , "hana.baskin@gmail.com", role = c("aut", "cre", "cph"))
Description: Provides curated ACC (Atlantic Coast Conference) baseball
    datasets at the player-season level, including traditional statistics
    and advanced sabermetric metrics such as weighted on-base average
    (wOBA), weighted runs created plus (wRC+), and fielding-independent
    pitching (FIP).
License: MIT + file LICENSE
Encoding: UTF-8
RoxygenNote: 8.0.0
Depends: R (>= 4.1.0)
LazyData: true
LazyDataCompression: xz
URL: https://github.com/hvb210/accbaseballr
BugReports: https://github.com/hvb210/accbaseballr/issues
NeedsCompilation: no
Packaged: 2026-07-13 19:04:46 UTC; hbaskin
Author: Hana Baskin [aut, cre, cph]
Maintainer: Hana Baskin <hana.baskin@gmail.com>
Repository: CRAN
Date/Publication: 2026-07-13 20:00:02 UTC
Built: R 4.6.1; ; 2026-07-13 23:40:35 UTC; unix
