% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data-pitching.R, R/data.R
\docType{data}
\name{pitching}
\alias{pitching}
\title{ACC Pitching Data}
\format{
A data frame with the following columns:
\describe{
\item{player_id}{Unique player-season identifier}
\item{Name}{Player first and last name}
\item{Age}{Player age during season}
\item{Season}{Year of season}
\item{Team}{ACC team}
\item{ERA}{Earned run average}
\item{GS}{Games started}
\item{IP}{Innings pitched}
\item{H}{Hits allowed}
\item{R}{Runs allowed}
\item{ER}{Earned runs allowed}
\item{HR}{Home runs allowed}
\item{BB}{Bases on balls}
\item{IBB}{Intentional bases on balls}
\item{SO}{Strikeouts}
\item{HBP}{Times hit by a pitch}
\item{BF}{Batters faced}
\item{WHIP}{Walks plus hits per inning pitched}
\item{throws}{Throwing handedness}
\item{K_pct}{Strikeout percentage}
\item{BB_pct}{Walk percentage}
\item{K_BB_pct}{Strikeout minus walk percentage}
\item{FIP}{Fielding independent pitching}
}

A data frame with one row per player-season and the following
columns:
\describe{
\item{Season}{Integer. The season (calendar year).}
\item{player_id}{Character. Unique player identifier.}
\item{Name}{Character. Player full name.}
\item{Age}{Character. Age of player in season.}
\item{Team}{Character. ACC team abbreviation or name.}
\item{ERA}{Numeric. Earned run average.}
\item{GS}{Integer. Games started.}
\item{IP}{Numeric. Innings pitched.}
\item{H}{Integer. Hits allowed.}
\item{R}{Integer. Runs allowed.}
\item{ER}{Integer. Earned runs allowed.}
\item{BB}{Integer. Walks allowed.}
\item{IBB}{Integer. Intentional walks.}
\item{SO}{Integer. Strikeouts.}
\item{HBP}{Integer. Hit by pitch.}
\item{HR}{Integer. Home runs allowed.}
\item{BF}{Integer. Batters faced.}
\item{WHIP}{Numeric. Walks plus hits per inning pitched.}
\item{throws}{Character. Throwing handedness: \code{"Right"}, \code{"Left"},
\code{"Both"} or \code{"Unkown"}.}
\item{K_pct}{Numeric. Strikeout percentage.}
\item{BB_pct}{Numeric. Walk percentage.}
\item{K_BB_pct}{Numeric. Strikeout minus walk percentage.}
\item{FIP}{Numeric. Fielding-independent pitching.}
}
}
\source{
Publicly available ACC baseball statistics transformed into sabermetric metrics for analysis.

Derived from publicly available ACC baseball data from
Sports-Reference (\url{https://www.sports-reference.com/}).
}
\usage{
pitching

pitching
}
\description{
Advanced pitching metrics for ACC pitchers including fielding-independent measures.

A dataset containing ACC baseball pitching statistics at the player-season
level, including traditional counting stats and advanced sabermetric
pitching metrics.
}
\details{
Player-season pitching metrics for ACC baseball.
}
\examples{
data(pitching)
head(pitching)
}
\keyword{datasets}
