% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/accbaseballr-package.R
\docType{package}
\name{accbaseballr}
\alias{accbaseballr-package}
\alias{accbaseballr}
\title{accbaseballr: ACC Baseball Statistics and Metrics}
\description{
Provides ACC baseball batting and pitching datasets with
advanced sabermetric metrics.
}
\seealso{
Useful links:
\itemize{
  \item \url{https://github.com/hvb210/accbaseballr}
  \item Report bugs at \url{https://github.com/hvb210/accbaseballr/issues}
}

}
\author{
\strong{Maintainer}: Hana Baskin \email{hana.baskin@gmail.com} [copyright holder]

Authors:
\itemize{
  \item Hana Baskin \email{hana.baskin@gmail.com} [copyright holder]
}

}
