% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R, R/league_context.R
\docType{data}
\name{league_context}
\alias{league_context}
\title{ACC baseball league context statistics}
\format{
A data frame with one row per season and the following columns:
\describe{
\item{Season}{Integer. The season (calendar year).}
\item{league_PA}{Integer. League-wide plate appearances.}
\item{league_H}{Integer. League-wide hits.}
\item{league_2B}{Integer. League-wide doubles hit.}
\item{league_3B}{Integer. League-wide triples hit.}
\item{league_HR}{Integer. League_wide home runs hit.}
\item{league_BB}{Integer. League-wide bases on balls.}
\item{league_HBP}{Integer. League-wide times hit by pitch.}
\item{league_SF}{Integer. League-wide sacrifice flies.}
\item{league_AB}{Integer. League-wide at bats.}
\item{league_BA}{Numeric. League-wide hits/at bats.}
\item{league_1B}{Integer. League-wide singles hit.}
\item{league_wOBA}{Numeric. League-wide weighted on-base average.}
\item{league_BB_rate}{Numeric. League-wide walk rate.}
\item{league_SO}{Integer. League-wide strikeouts.}
\item{p_league_BB}{Integer. League-wide bases on balls (pitching).}
\item{p_league_HR}{Integer. League-wide home runs allowed.}
\item{league_IP}{Numeric. League-wide innings pitched.}
\item{league_K_per_9}{Numeric. League-wide strikeouts per nine innings.}
\item{league_BB_per_9}{Numeric. League-wide bases on balls per nine innings.}
\item{league_HR_per_9}{Numeric. League-wide home runs allowed per nine innings.}
}

A data frame with one row per season:
\describe{
\item{Season}{Season year}
\item{league_PA}{League-wide plate appearances}
\item{league_H}{League-wide hits}
\item{league_2B}{League-wide doubles hit}
\item{league_3B}{League-wide triples hit}
\item{league_HR}{League_wide home runs hit}
\item{league_BB}{League-wide bases on balls}
\item{league_HBP}{League-wide times hit by pitch}
\item{league_SF}{League-wide sacrifice flies}
\item{league_AB}{League-wide at bats}
\item{league_BA}{League-wide hits/at bats}
\item{league_1B}{League-wide singles hit}
\item{league_wOBA}{League-wide weighted on-base average}
\item{league_BB_rate}{walk rate}
\item{league_SO}{League-wide strikeouts}
\item{p_league_BB}{League-wide bases on balls (pitching)}
\item{p_league_HR}{League-wide home runs allowed}
\item{league_IP}{League-wide innings pitched}
\item{league_K_per_9}{League-wide strikeouts per nine innings}
\item{league_BB_per_9}{League-wide bases on balls per nine innings}
\item{league_HR_per_9}{League-wide home runs allowed per nine innings}
}
}
\source{
Derived from publicly available ACC baseball data from
Sports-Reference (\url{https://www.sports-reference.com/}).

Publicly available ACC baseball statistics transformed into sabermetric metrics for analysis.
}
\usage{
league_context

league_context
}
\description{
A dataset containing league-average statistics used for normalization
and calculation of advanced metrics such as wOBA and wRC+.

Season-level offensive environment metrics used for normalization of player statistics.
}
\examples{
data(league_context)
head(league_context)
}
\keyword{datasets}
