% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data-players.R, R/data.R
\docType{data}
\name{players}
\alias{players}
\title{ACC Player Data}
\format{
A data frame with the following columns:
\describe{
\item{player_id}{Unique player identifier}
\item{Name}{Player first and last name}
\item{bats}{Batting handedness}
\item{throws}{Throwing handedness}
}

A data frame with one row per player and the following columns:
\describe{
\item{Name}{Character. Player full name.}
\item{player_id}{Character. Unique player identifier.}
\item{bats}{Character. Batting handedness: \code{"Right"}, \code{"Left"},
\code{"Both"} or \code{"Unkown"}.}
\item{throws}{Character. Throwing handedness: \code{"Right"}, \code{"Left"},
\code{"Both"} or \code{"Unkown"}.}
}
}
\source{
Compiled from publicly available roster information from Sports-Reference.

Derived from publicly available ACC baseball data from
Sports-Reference (\url{https://www.sports-reference.com/}).
}
\usage{
players

players
}
\description{
Basic player identification information used to join batting and pitching datasets.

A dataset containing player-level metadata for ACC baseball players,
including handedness information.
}
\details{
Player metadata for ACC baseball players.
}
\examples{
data(players)
head(players)
}
\keyword{datasets}
